@@ -8,6 +8,7 @@ from .lib import timezone
 __all__ = [
     'CanonicalException',
     'ImproperlyConfigured',
+    'ProgrammingError',
 ]
 
 
@@ -16,6 +17,11 @@ class ImproperlyConfigured(RuntimeError):
     pass
 
 
+class ProgrammingError(Exception):
+    """Raised when parts of the framework are implemented incorrectly."""
+    pass
+
+
 class CanonicalExceptionMetaclass(type):
 
     def __new__(cls, name, bases, attrs):
