@@ -31,7 +31,7 @@ def load(path: str, *args, **kwargs) -> dict:
         return None
     files = list([path] if not os.path.isdir(path) else glob.glob(f'{path}/*'))
     etc = {}
-    for fn in files:
+    for fn in sorted(files):
         with open(fn, 'r') as f:
             etc.update(yaml.safe_load(render(f.read(), **kwargs)))
     return DTO.fromdict(etc)
